@@ -463,18 +463,26 @@ add_suggestion_menus (GtkSpellChecker *spell, const char *word, GtkWidget *topme
 
   /* + Add to Dictionary */
   label = g_strdup_printf (_("Add \"%s\" to Dictionary"), word);
+#if GTK_CHECK_VERSION(3,9,0)
+  mi = gtk_menu_item_new_with_label (label);
+#else
   mi = gtk_image_menu_item_new_with_label (label);
-  g_free (label);
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi),
                  gtk_image_new_from_stock (GTK_STOCK_ADD, GTK_ICON_SIZE_MENU));
+#endif
+  g_free (label);
   g_signal_connect (mi, "activate", G_CALLBACK (add_to_dictionary), spell);
   gtk_widget_show_all (mi);
   gtk_menu_shell_insert (GTK_MENU_SHELL (topmenu), mi, menu_position++);
 
   /* - Ignore All */
+#if GTK_CHECK_VERSION(3,9,0)
+  mi = gtk_menu_item_new_with_label (_("Ignore All"));
+#else
   mi = gtk_image_menu_item_new_with_label (_("Ignore All"));
   gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi),
               gtk_image_new_from_stock (GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU));
+#endif
   g_signal_connect (mi, "activate", G_CALLBACK (ignore_all), spell);
   gtk_widget_show_all (mi);
   gtk_menu_shell_insert (GTK_MENU_SHELL (topmenu), mi, menu_position++);
@@ -541,10 +549,14 @@ build_languages_menu (GtkSpellChecker *spell)
 #ifdef HAVE_ISO_CODES
       if (spell->priv->decode_codes == TRUE)
         {
-          const gchar *lang_name;
-          const gchar *country_name;
+          const gchar *lang_name = "\0";
+          const gchar *country_name = "\0";
+          gchar *label;
           codetable_lookup (lang_tag, &lang_name, &country_name);
-          gchar *label = g_strdup_printf ("%s (%s)", lang_name, country_name);
+          if (strlen (country_name) != 0)
+            label = g_strdup_printf ("%s (%s)", lang_name, country_name);
+          else
+            label = g_strdup_printf ("%s", lang_name);
           mi = gtk_radio_menu_item_new_with_label (menu_group, label);
           g_free (label);
         }
@@ -1099,7 +1111,7 @@ gtk_spell_checker_get_language_list (void)
 
 /**
  * gtk_spell_checker_decode_language_code:
- * @lang: The language locale specifier (i.e. "en", or "en_US").
+ * @lang: The language locale specifier (i.e. "en_US").
  *
  * Translates the language code to a human readable format
  * (i.e. "en_US" -> "English (United States)").
@@ -1115,14 +1127,17 @@ gchar*
 gtk_spell_checker_decode_language_code (const gchar *lang)
 {
 #ifdef HAVE_ISO_CODES
-  const gchar *lang_name;
-  const gchar *country_name;
+  const gchar *lang_name = "\0";
+  const gchar *country_name = "\0";
   if (codetable_ref_cnt == 0)
     codetable_init ();
   codetable_lookup (lang, &lang_name, &country_name);
   if (codetable_ref_cnt == 0)
     codetable_free ();
-  return g_strdup_printf ("%s (%s)", lang_name, country_name);
+  if (strlen (country_name) != 0)
+    return g_strdup_printf ("%s (%s)", lang_name, country_name);
+  else
+    return g_strdup_printf ("%s", lang_name);
 #else
   return g_strdup (lang);
 #endif
@@ -1131,7 +1146,7 @@ gtk_spell_checker_decode_language_code (const gchar *lang)
 /**
  * gtk_spell_checker_set_language:
  * @spell: The #GtkSpellChecker object.
- * @lang: (allow-none): The language to use, as a locale specifier (i.e. "en", or "en_US").
+ * @lang: (allow-none): The language to use, as a locale specifier (i.e. "en_US").
  * If #NULL, attempt to use the default system locale (LANG).
  * @error: (out) (allow-none): Return location for error.
  *
